@@ -49,6 +49,7 @@ protected:
     void scaledBlurBackground();
     void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
     void moveEvent(QMoveEvent *event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
 
 private:
     virtual const QScreen * currentScreen();
@@ -58,8 +59,6 @@ private:
     QString m_lastBlurUrl;
     QPixmap m_pixmap;
     QString m_defaultBg;
-    QPixmapCache::Key m_cacheNormalKey;
-    QPixmapCache::Key m_cacheBlurKey;
     BackgroundManager *m_bgManager;
     bool m_useSolidBackground;
 };
