@@ -358,8 +358,7 @@ void AppsListModel::setDrawBackground(bool draw)
     if (draw == m_drawBackground) return;
 
     m_drawBackground = draw;
-
-    emit QAbstractItemModel::dataChanged(QModelIndex(), QModelIndex());
+    Q_EMIT QAbstractItemModel::dataChanged(QModelIndex(), QModelIndex());
 }
 
 /**
