@@ -108,7 +108,8 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     , m_modeToggleBtn(new ModeToggleButton(this))
     , m_searcherEdit(new DSearchEdit(this))
     , m_enterSearchEdit(false)
-    , m_curScreen(m_appsManager->currentScreen())
+    , m_dockFrontInfc(new DBusDockInterface(this))
+    , m_currentAppListIndex(m_appsView->currentIndex().row())
 {
     if (!getDConfigValue("enableFullScreenMode", true).toBool())
         m_modeToggleBtn->hide();
@@ -229,6 +230,7 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     connect(m_menuWorker.get(), &MenuWorker::unInstallApp, this, static_cast<void (WindowedFrame::*)(const QModelIndex &)>(&WindowedFrame::uninstallApp));
     connect(m_menuWorker.get(), &MenuWorker::menuAccepted, m_delayHideTimer, static_cast<void (QTimer::*)()>(&QTimer::start));
     connect(m_menuWorker.get(), &MenuWorker::appLaunched, this, &WindowedFrame::hideLauncher, Qt::QueuedConnection);
+    connect(m_menuWorker.get(), &MenuWorker::notifyMenuDisplayState, m_appsView, &AppListView::setMenuVisible);
 
     connect(m_appsView, &QListView::clicked, m_appsManager, &AppsManager::launchApp, Qt::QueuedConnection);
     connect(m_appsView, &QListView::clicked, this, &WindowedFrame::hideLauncher, Qt::QueuedConnection);
@@ -236,9 +238,12 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     connect(m_appsView, &AppListView::popupMenuRequested, m_menuWorker.get(), &MenuWorker::showMenuByAppItem);
     connect(m_menuWorker.get(), &MenuWorker::menuAccepted, m_appsView, &AppListView::menuHide); // 当菜单消失时通知菜单结束了
     connect(m_appsView, &AppListView::requestSwitchToCategory, this, &WindowedFrame::switchToCategory);
-
-    connect(m_appsView, &AppListView::requestEnter, m_appsModel, &AppsListModel::setDrawBackground);
     connect(m_appsView, &AppListView::requestEnter, m_searchModel, &AppsListModel::setDrawBackground);
+    connect(m_appsView, &AppListView::requestEnter, m_menuWorker.get(), [this](bool state) {
+        if (!m_menuWorker.get()->isMenuVisible() && state) {
+            m_appsModel->setDrawBackground(state);
+        }
+    });
 
     connect(m_appsManager, &AppsManager::requestTips, this, &WindowedFrame::showTips);
     connect(m_appsManager, &AppsManager::requestHideTips, this, &WindowedFrame::hideTips);
@@ -251,9 +256,7 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     QTimer::singleShot(1, this, &WindowedFrame::onWMCompositeChanged);
     onOpacityChanged(m_appearanceInter->opacity());
 
-    connect(m_curScreen, &QScreen::geometryChanged, this, &WindowedFrame::onScreenInfoChange);
-    connect(m_curScreen, &QScreen::orientationChanged, this, &WindowedFrame::onScreenInfoChange);
-    connect(qApp, &QApplication::primaryScreenChanged, this, &WindowedFrame::onScreenInfoChange);
+    connect(m_dockFrontInfc, &DBusDockInterface::geometryChanged, this, &WindowedFrame::onDockGeometryChanged);
 
     connect(this, &WindowedFrame::visibleChanged, this, &WindowedFrame::onHideMenu);
 
@@ -291,6 +294,7 @@ void WindowedFrame::showLauncher()
 
     // 启动器跟随任务栏位置
     adjustPosition();
+
     m_cornerPath = getCornerPath(m_anchoredCornor);
     m_windowHandle.setClipPath(m_cornerPath);
     show();
@@ -310,6 +314,7 @@ void WindowedFrame::hideLauncher()
     recoveryAll();
 
     hide();
+    m_appsView->setMenuVisible(false);
 }
 
 bool WindowedFrame::visible()
@@ -525,7 +530,12 @@ void WindowedFrame::launchCurrentApp()
     if (currentIdx.isValid() && currentIdx.model() == m_appsView->model()) {
         m_appsManager->launchApp(currentIdx);
     } else {
-        m_appsManager->launchApp(m_appsView->model()->index(0, 0));
+        if (currentIdx.isValid()) {
+            m_appsManager->launchApp(m_appsView->model()->index(0, 0));
+        } else {
+            qWarning() << "Curren index is not valid";
+            return;
+        }
     }
 
     hideLauncher();
@@ -763,6 +773,11 @@ QVariant WindowedFrame::inputMethodQuery(Qt::InputMethodQuery prop) const
 void WindowedFrame::regionMonitorPoint(const QPoint &point, int flag)
 {
     Q_UNUSED(flag);
+
+    if (isWaylandDisplay()) {
+        return;
+    }
+
     auto windowList = DWindowManagerHelper::instance()->currentWorkspaceWindows();
 
     for (auto window : windowList) {
@@ -807,6 +822,11 @@ bool WindowedFrame::eventFilter(QObject *watched, QEvent *event)
             m_searcherEdit->lineEdit()->clearFocus();
     }
 
+    // 第一次弹出菜单时会将界面设置为ApplicationDeactivate状态，导致再次弹出菜单时会满足条件从而隐藏界面
+    // 此时需要判断下是否因为弹出菜单导致的界面ApplicationDeactivate状态
+    if (isActiveWindow() && watched == qApp && event->type() == QEvent::ApplicationDeactivate && !m_menuWorker->isMenuShown()) {
+        hideLauncher();
+    }
     return QWidget::eventFilter(watched, event);
 }
 
@@ -893,6 +913,8 @@ void WindowedFrame::onToggleFullScreen()
     if (delegate)
         delegate->setActived(false);
 
+    m_modeToggleBtn->setHovered(false);
+
     // 全屏状态标识
     m_calcUtil->setFullScreen(true);
 
@@ -1009,26 +1031,20 @@ void WindowedFrame::onOpacityChanged(const double value)
     setMaskAlpha(value * 255);
 }
 
-void WindowedFrame::onScreenInfoChange()
+void WindowedFrame::onDockGeometryChanged()
 {
-    m_curScreen->disconnect();
-    m_curScreen = m_appsManager->currentScreen();
-
     adjustSize();
     updatePosition();
     m_cornerPath = getCornerPath(m_anchoredCornor);
     m_windowHandle.setClipPath(m_cornerPath);
-
-    connect(m_curScreen, &QScreen::geometryChanged, this, &WindowedFrame::onScreenInfoChange);
-    connect(m_curScreen, &QScreen::orientationChanged, this, &WindowedFrame::onScreenInfoChange);
 }
 
 void WindowedFrame::updatePosition()
 {
-   // 该接口获取数据是翻转后的数据
-   DBusDockInterface inter;
-   QRect dockGeo = inter.geometry();
-   QRect dockRect = QRect(scaledPosition(dockGeo.topLeft()),scaledPosition(dockGeo.bottomRight()));
+    if (!m_dockFrontInfc || !m_dockInter)
+        return;
+
+    QRect dockRect = m_dockFrontInfc->geometry();
 
     int dockSpacing = 0;
     if (m_dockInter->displayMode() == DOCK_FASHION)
@@ -1060,6 +1076,7 @@ void WindowedFrame::onHideMenu()
 {
     if (m_menuWorker.get() && !isVisible())
         m_menuWorker.get()->onHideMenu();
+    m_currentAppListIndex = -1;
 }
 
 void WindowedFrame:: paintEvent(QPaintEvent *e)
