@@ -1,11 +1,16 @@
+#include <DLog>
+
 #include <QApplication>
 #include <QDebug>
 
-#include <DLog>
+#ifdef SANITIZER_CHECK
+#include <sanitizer/asan_interface.h>
+#endif
 
 #include <gtest/gtest.h>
 
 DCORE_USE_NAMESPACE
+
 int main(int argc, char **argv)
 {
     // gerrit编译时没有显示器，需要指定环境变量
@@ -19,5 +24,9 @@ int main(int argc, char **argv)
     ::testing::InitGoogleTest(&argc, argv);
     int ret = RUN_ALL_TESTS();
     qDebug() << "end dde-launcher test cases ..............";
+
+#ifdef SANITIZER_CHECK
+    __sanitizer_set_report_path("asan.log");
+#endif
     return ret;
 }
